@@ -8,6 +8,7 @@ use base 'Exporter';
 
 use Term::ReadKey;
 use Csistck::Test;
+use Csistck::Test::Return;
 
 our @EXPORT_OK = qw/
     prompt
@@ -23,15 +24,15 @@ sub prompt {
     say("What would you like to:");
     my @choices = ();
     # Repair
-    if ($test->has_repair()) {
+    if ($test->can('repair')) {
         say("  Y : Repair");
         push(@choices, 'Y');
     }
     # Skip
     say("  N : Skip");
     push(@choices, 'n');
-    # DIff
-    if ($test->has_diff()) {
+    # Diff
+    if ($test->can('diff')) {
         say("  D : Diff");
         push(@choices, 'd');
     }
@@ -42,16 +43,24 @@ sub prompt {
     say($action); 
     ReadMode 0;
     
+    # Execute and return, based on input. Return value is used for processing
+    # on_repair operations.
     given ($action) {
         when (/[Yy\n]/) { 
-            $test->repair() if ($test->has_repair());
+            return $test->execute('repair') if ($test->can('repair'));
         }
         when (/[Dd]/) { 
             # Show diff, loop through prompt again
-            $test->diff() if ($test->has_diff());
-            prompt($test);
+            $test->execute('diff') if ($test->can('diff'));
+            return prompt($test);
+        }
+        default {
+            return Csistck::Test::Return->new(
+                resp => 0,
+                msg => 'Missing function',
+                desc => $test->desc
+            );
         }
-        default {}
     }
 }
 
